@@ -11,7 +11,7 @@ Usage::
 """
 import sys
 from datetime import datetime
-from typing import Any, Dict, List
+from typing import IO, Any, Dict, List, Union
 
 if sys.version_info >= (3, 8):
     from typing import Literal
@@ -123,6 +123,7 @@ __all__ = (
     "ApplicationConfigurationUpdateTypeDef",
     "CloudWatchLoggingOptionTypeDef",
     "CloudWatchLoggingOptionUpdateTypeDef",
+    "CreateApplicationPresignedUrlResponseTypeDef",
     "CreateApplicationResponseTypeDef",
     "DeleteApplicationCloudWatchLoggingOptionResponseTypeDef",
     "DeleteApplicationInputProcessingConfigurationResponseTypeDef",
@@ -205,7 +206,7 @@ _RequiredApplicationDetailTypeDef = TypedDict(
     {
         "ApplicationARN": str,
         "ApplicationName": str,
-        "RuntimeEnvironment": Literal["SQL-1_0", "FLINK-1_6", "FLINK-1_8"],
+        "RuntimeEnvironment": Literal["SQL-1_0", "FLINK-1_6", "FLINK-1_8", "FLINK-1_11"],
         "ApplicationStatus": Literal[
             "DELETING",
             "STARTING",
@@ -288,7 +289,7 @@ ApplicationSummaryTypeDef = TypedDict(
             "FORCE_STOPPING",
         ],
         "ApplicationVersionId": int,
-        "RuntimeEnvironment": Literal["SQL-1_0", "FLINK-1_6", "FLINK-1_8"],
+        "RuntimeEnvironment": Literal["SQL-1_0", "FLINK-1_6", "FLINK-1_8", "FLINK-1_11"],
     },
 )
 
@@ -364,7 +365,11 @@ CodeContentDescriptionTypeDef = TypedDict(
 
 CodeContentTypeDef = TypedDict(
     "CodeContentTypeDef",
-    {"TextContent": str, "ZipFileContent": bytes, "S3ContentLocation": "S3ContentLocationTypeDef"},
+    {
+        "TextContent": str,
+        "ZipFileContent": Union[bytes, IO[bytes]],
+        "S3ContentLocation": "S3ContentLocationTypeDef",
+    },
     total=False,
 )
 
@@ -372,7 +377,7 @@ CodeContentUpdateTypeDef = TypedDict(
     "CodeContentUpdateTypeDef",
     {
         "TextContentUpdate": str,
-        "ZipFileContentUpdate": bytes,
+        "ZipFileContentUpdate": Union[bytes, IO[bytes]],
         "S3ContentLocationUpdate": "S3ContentLocationUpdateTypeDef",
     },
     total=False,
@@ -1195,6 +1200,10 @@ class CloudWatchLoggingOptionUpdateTypeDef(
     pass
 
 
+CreateApplicationPresignedUrlResponseTypeDef = TypedDict(
+    "CreateApplicationPresignedUrlResponseTypeDef", {"AuthorizedUrl": str}, total=False
+)
+
 CreateApplicationResponseTypeDef = TypedDict(
     "CreateApplicationResponseTypeDef", {"ApplicationDetail": "ApplicationDetailTypeDef"}
 )
